@@ -26,6 +26,7 @@ from ._interface import (
     CacheInterfaceAttrs,
     DeclareClassImplements,
     GetImplementedInterfaces,
+    GetProxy,
     ImplementsInterface,
     Interface,
     InterfaceError,
@@ -47,6 +48,7 @@ __all__ = [
     "CacheInterfaceAttrs",
     "DeclareClassImplements",
     "GetImplementedInterfaces",
+    "GetProxy",
     "IAdaptable",
     "ImplementsInterface",
     "Interface",
